@@ -2,8 +2,7 @@ mod error;
 mod open_options;
 mod vfs;
 
-pub mod backend;
-
+pub use async_trait::async_trait;
 pub use error::*;
 pub use open_options::*;
 pub use vfs::*;
